@@ -67,7 +67,7 @@ class TorchTagger:
         """
         all_preds = []
         all_y = []
-        all_probs = []
+        all_logprobs = []
 
         for idx, batch in enumerate(iterator):
             if torch.cuda.is_available():
@@ -78,13 +78,14 @@ class TorchTagger:
             probabilities, predictions = torch.max(y_pred.cpu().data, 1)
             all_preds.extend(predictions.numpy())
             all_y.extend(batch.label.numpy())
-            all_probs.extend(probabilities.numpy())
+            all_logprobs.extend(probabilities.numpy())
         
         # flatten predictions
         all_preds = np.array(all_preds).flatten()
-        all_probs = np.array(all_probs).flatten()
+        all_logprobs = np.array(all_logprobs).flatten()
 
         #add small epsilon to probabilities to prevent log(0) in loss calulation
+        all_probs = np.exp(all_logprobs)
         all_probs = np.clip(all_probs, 1e-5, 1-1e-5)
 
         all_y = np.array(all_y)
@@ -95,7 +96,6 @@ class TorchTagger:
         report.val_loss = -np.sum(all_y*np.log(all_probs) + (1-all_y)*np.log(1-all_probs))/len(all_y)
         return report
 
-
     def train(self, data_sample, num_epochs=5):
         """
         Trains model based on data sample.
@@ -112,9 +112,12 @@ class TorchTagger:
         model = self.model_arch(self.config, len(text_field.vocab), text_field.vocab.vectors, self.evaluate_model)
         # check cuda
         if torch.cuda.is_available():
+            print("GPU available. Using GPU.")
             model.cuda()
             # clear cuda cache prior to training
             torch.cuda.empty_cache()
+        else:
+            print("No GPU available. Are you sure you want to train the tagger using CPU?")
         # train
         model.train()
         optimizer = optim.SGD(model.parameters(), lr=self.config.lr)
