@@ -18,6 +18,7 @@ class TaggingReport:
         self.recall = recall_score(y_test, y_pred, average=average)
         self.accuracy = accuracy_score(y_test, y_pred)
         self.training_loss = None
+        self.val_loss = None
 
         
     def to_dict(self):
@@ -27,5 +28,6 @@ class TaggingReport:
             "recall": round(self.recall, 5),
             "confusion_matrix": self.confusion.tolist(),
             "accuracy": round(self.accuracy, 5),
-            "training_loss": round(self.training_loss.astype(float), 5)
+            "training_loss": round(self.training_loss.astype(float), 5),
+            "val_loss": round(self.val_loss.astype(float), 5)
         }
